"""PyAnsys Tools Report package."""

# Improving accessibility to the pyansys-tools-report resources

from ansys.tools.report._version import __version__, version
from ansys.tools.report.report import Report
